Introduction
============

Motivation
----------

Features
--------

Getting Started
---------------

Once you have the package installed :any:`installed <installation>` you
can check out the :any:`quickstart <quick_start>` to get a rough idea of
how it works.

Then you can either read the :any:`user's guide <users_guide>` or head
on to the :any:`tutorials <../tutorials>` or execute the
`examples <../../examples>`__ in the source code.

For a complete description of the modules and their components check out
the :any:`API documentation <../api/modules>`.

Other useful resources
----------------------

Alternatives
------------
